# Software Documentation

## Software Configuration

![tracing](https://www.plantuml.com/plantuml/proxy?cache=no&src=https://raw.githubusercontent.com/NewTec-GmbH/pyTRLCConverter/main/doc/configuration/tracing.puml)

## Software Architecture

The following section describes the high level software architecture.

### Use Cases

![use_cases](https://www.plantuml.com/plantuml/proxy?cache=no&src=https://raw.githubusercontent.com/NewTec-GmbH/pyTRLCConverter/main/doc/architecture/use_cases.puml)

### Context Diagram

![context_diagram](https://www.plantuml.com/plantuml/proxy?cache=no&src=https://raw.githubusercontent.com/NewTec-GmbH/pyTRLCConverter/main/doc/architecture/context_diagram.puml)

### Class Diagram

![class_diagram](https://www.plantuml.com/plantuml/proxy?cache=no&src=https://raw.githubusercontent.com/NewTec-GmbH/pyTRLCConverter/main/doc/architecture/class_diagram.puml)

### Sequence Diagram

![sequence_diagram](https://www.plantuml.com/plantuml/proxy?cache=no&src=https://raw.githubusercontent.com/NewTec-GmbH/pyTRLCConverter/main/doc/architecture/sequence_diagram.puml)
